@@ -64,6 +64,9 @@ ACCOUNT_AUTHENTICATED_LOGIN_REDIRECTS = False
 ACCOUNT_EMAIL_CONFIRMATION_AUTHENTICATED_REDIRECT_URL = '/'
 ACCOUNT_SESSION_REMEMBER = False
 
+# case insensitive username
+ACCOUNT_PRESERVE_USERNAME_CASING = True
+
 SOCIALACCOUNT_PROVIDERS = {}
 
 if 'google' in DJANGO_SSO_APP_SOCIALACCOUNT_PROVIDERS:
