@@ -1,7 +1,7 @@
 from django.conf.urls import url
 from django.urls import include, path
-from django.conf import settings
-from django.views.generic.base import RedirectView
+#from django.conf import settings
+#from django.views.generic.base import RedirectView
 
 from ..core.apps.users.urls import urlpatterns as users_urls
 from ..core.apps.users.urls import extra_urlpatterns as users_extra_urls
@@ -13,14 +13,14 @@ from ..core.apps.services.urls import urlpatterns as services_urls
 from ..core.apps.devices.urls import urlpatterns as devices_urls
 from ..core.apps.passepartout.urls import urlpatterns as passepartout_urls
 
-from ..core.urls import allauth_urlpatterns
+from ..core.urls import allauth_urlpatterns, allauth_i18n_urlpatterns
 from ..core.api.urls import allauth_api_urlpatterns
 
 django_sso_app_profile_urlpatterns = [
     path('profile/', ProfileView.as_view(), name='profile'),
     path('profile/update/', ProfileUpdateView.as_view(), name='profile.update'),
 ]
-django_sso_app_i18n_urlpatterns = django_sso_app_profile_urlpatterns
+django_sso_app_i18n_urlpatterns = django_sso_app_profile_urlpatterns + allauth_i18n_urlpatterns
 django_sso_app_urlpatterns = allauth_urlpatterns
 django_sso_app_api_urlpatterns = allauth_api_urlpatterns
 
