@@ -58,9 +58,10 @@ FILE_UPLOAD_HANDLERS = [
 APPEND_SLASH = True
 
 # extra
-from .extra import EXTRA_APPS
+from .extra import EXTRA_APPS, EXTRA_ADMINS
 
 # context_processors
+DEPLOYMENT_ENV = env("DEPLOYMENT_ENV", default='dev' if DEBUG else 'production')
 REPOSITORY_REV = env("REPOSITORY_REV", default=None)
 EMAILS_DOMAIN = env('EMAILS_DOMAIN', default=APP_DOMAIN) # domain name specified in email templates
 EMAILS_SITE_NAME = env('EMAILS_SITE_NAME', default=COOKIE_DOMAIN) # site name specified in email templates
@@ -136,6 +137,9 @@ THIRD_PARTY_APPS = [
     "django_filters",
     "django_celery_beat",
     "django_celery_results",
+
+    "rpc4django",
+
     "drf_yasg",
 ]
 
@@ -234,6 +238,7 @@ STATIC_ROOT = str(PUBLIC_ROOT("static"))  # pai
 STATIC_URL = "/static/"
 # https://docs.djangoproject.com/en/dev/ref/contrib/staticfiles/#std:setting-STATICFILES_DIRS
 STATICFILES_DIRS = [str(BACKEND_DIR.path("static"))]  # pai
+
 # https://docs.djangoproject.com/en/dev/ref/contrib/staticfiles/#staticfiles-finders
 STATICFILES_FINDERS = [
     "django.contrib.staticfiles.finders.FileSystemFinder",
@@ -274,11 +279,13 @@ TEMPLATES = [
                 "django.template.context_processors.tz",
                 "django.contrib.messages.context_processors.messages",
 
+                # "django_sso_app.backend.utils.context_processors.settings_context",  # pai (dangerous)
+                'django_sso_app.backend.utils.context_processors.get_stats_info',  # pai
+
                 # django-sso-app
                 'django_sso_app.core.context_processors.django_sso_app_context',
 
                 # extra
-                'django_sso_app.backend.context_processors.get_repository_rev',
                 'django_sso_app.backend.context_processors.django_meta',
                 'django_sso_app.backend.context_processors.google_api_settings',
                 'django_sso_app.backend.context_processors.raven_js_dsn_settings',
@@ -296,7 +303,7 @@ CRISPY_TEMPLATE_PACK = "bootstrap4"
 # FIXTURES
 # ------------------------------------------------------------------------------
 # https://docs.djangoproject.com/en/dev/ref/settings/#fixture-dirs
-FIXTURE_DIRS = (str(ROOT_DIR.path("fixtures")),)
+# FIXTURE_DIRS = (str(ROOT_DIR.path("fixtures")),)  # prevent external fixtures import error
 
 # SECURITY
 # ------------------------------------------------------------------------------
@@ -349,6 +356,10 @@ EMAIL_TIMEOUT = 5
 ADMIN_URL = "admin/"
 # https://docs.djangoproject.com/en/dev/ref/settings/#admins
 ADMINS = [("""Luca Bertuol""", "paiuolo@gmail.com")]
+# extra
+if len(EXTRA_ADMINS):
+    ADMINS = EXTRA_ADMINS
+
 # https://docs.djangoproject.com/en/dev/ref/settings/#managers
 MANAGERS = ADMINS
 
