@@ -11,6 +11,8 @@ from django.conf import settings
 from django.conf.urls.i18n import i18n_patterns
 from django.utils.translation import gettext_lazy as _
 from django.contrib.auth.decorators import login_required
+# rpc
+from rpc4django.views import serve_rpc_request
 
 # django-sso-app
 from ..urls import (urlpatterns as django_sso_app__urlpatterns,
@@ -96,6 +98,8 @@ if settings.DEBUG:
 api_urlpatterns += [
     url(r'^api/v1/_stats/$', StatsView.as_view(), name='stats'),
 
+    url(r'^rpc/v2/$', serve_rpc_request),
+
     # your api here
 ]
 
