@@ -21,7 +21,7 @@ from allauth.account import app_settings as allauth_app_settings
 
 from .mixins import TryAuthenticateMixin
 from .utils import set_session_key, check_user_can_login
-from .exceptions import UnsubscribedUserException  #, DectivatedUserException, AdminUserCanNotLoginException
+from .exceptions import UnsubscribedUserException, DjangoStaffUsersCanNotLoginException  #, DectivatedUserException
 from .apps.emails.models import EmailAddress
 from .apps.devices.models import Device
 from .apps.devices.utils import get_request_device
@@ -30,7 +30,7 @@ from .apps.profiles.utils import get_or_create_user_profile, update_profile
 from .apps.profiles.models import Profile
 from .apps.passepartout.utils import get_passepartout_login_redirect_url
 from .tokens.utils import get_request_jwt_fingerprint, get_request_jwt, renew_response_jwt
-from .permissions import is_authenticated, is_staff
+from .permissions import is_authenticated, is_staff, is_django_staff
 from . import app_settings
 
 logger = logging.getLogger('django_sso_app.core')
@@ -121,7 +121,9 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
             django_login(request, user)
 
             if is_authenticated(user):
-                if not user.is_superuser:
+                if is_django_staff(user):
+                   raise DjangoStaffUsersCanNotLoginException()
+                else:
                     # setting up request user
                     setattr(request, 'user', user)
 
@@ -356,7 +358,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         user = self.try_authenticate(username, email, password)
         requesting_user = self.request.user
 
-        if not requesting_user.is_superuser and not user.is_superuser:
+        if not is_django_staff(user):
             profile = user.sso_app_profile
             logger.info('Completely unsubscribing Profile "{}"'.format(profile))
 
@@ -379,7 +381,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
 
         requesting_user = self.request.user
 
-        if not requesting_user.is_superuser and not user.is_superuser:
+        if not is_django_staff(requesting_user):
             received_jwt = get_request_jwt(self.request)
 
             if received_jwt is not None:
