@@ -88,7 +88,7 @@ class TestLogin(UserTestCase):
         second_rev = migrated_profile.sso_rev
         self.assertEqual(previus_rev, second_rev)
 
-    def test_admin_user_can_not_login_from_api_views(self):
+    def test_django_superuser_can_not_login_from_api_views(self):
         response = self.client.post(
             reverse('rest_login'),
             data=self.valid_admin_login
@@ -106,7 +106,28 @@ class TestLogin(UserTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-        self.assertFalse(has_jwt_cookie, 'admin receives jwt')
+        self.assertFalse(has_jwt_cookie, 'superuser receives jwt')
+        self.assertEqual(jwt_cookie, None, 'jwt is still valid')
+
+    def test_django_staff_user_can_not_login_from_api_views(self):
+        response = self.client.post(
+            reverse('rest_login'),
+            data=self.valid_staff_login
+        )
+
+        cookies = response.client.cookies.items()
+
+        jwt_cookie = None
+        has_jwt_cookie = False
+        for (key, val) in cookies:
+            if key == "jwt":
+                has_jwt_cookie = True
+                jwt_cookie = val
+                break
+
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
+
+        self.assertFalse(has_jwt_cookie, 'staff receives jwt')
         self.assertEqual(jwt_cookie, None, 'jwt is still valid')
 
 
@@ -182,7 +203,7 @@ class TestLogout(UserTestCase):
                          'api logout is deleting all user devices')
 
 
-class TestRegister(UserTestCase):
+class TestSignup(UserTestCase):
 
     def test_can_register(self):
         response = self.client.post(
