@@ -7,7 +7,7 @@ from django.dispatch import receiver
 
 from allauth.account.adapter import get_adapter
 
-from ....permissions import is_staff
+from ....permissions import is_django_staff
 from ...devices.models import Device
 from ...groups.models import Group
 from ...profiles.models import Profile
@@ -24,27 +24,30 @@ adapter = get_adapter()
 @receiver(pre_save, sender=Device)
 def create_device_apigw_jwt(sender, instance, **kwargs):
     profile = instance.profile
-    apigateway_consumer_id = get_profile_apigw_consumer_id(profile)
+    user = profile.user
 
-    logger.info('Profile "{}" has apigateway_consumer_id "{}"'.format(profile, apigateway_consumer_id))
+    if not is_django_staff(user):
+        apigateway_consumer_id = get_profile_apigw_consumer_id(profile)
 
-    if instance._state.adding:
-        device = instance
+        logger.info('Profile "{}" has apigateway_consumer_id "{}"'.format(profile, apigateway_consumer_id))
 
-        logger.info('Creating apigw JWT for Device "{}"'.format(device))
+        if instance._state.adding:
+            device = instance
 
-        status_code, r1 = create_apigw_consumer_jwt(device.profile)
-        if status_code != 201:
-            # delete_apigw_consumer(username)
-            logger.error(
-                'Error ({}) creating apigw consumer JWT, "{}"'.format(
-                    status_code, r1))
-            raise Exception(
-                'Error ({}) creating apigw consumer jwt'.format(status_code))
+            logger.info('Creating apigw JWT for Device "{}"'.format(device))
 
-        device.apigw_jwt_id = r1.get('id')
-        device.apigw_jwt_key = r1.get('key')
-        device.apigw_jwt_secret = r1.get('secret')
+            status_code, r1 = create_apigw_consumer_jwt(device.profile)
+            if status_code != 201:
+                # delete_apigw_consumer(username)
+                logger.error(
+                    'Error ({}) creating apigw consumer JWT, "{}"'.format(
+                        status_code, r1))
+                raise Exception(
+                    'Error ({}) creating apigw consumer jwt'.format(status_code))
+
+            device.apigw_jwt_id = r1.get('id')
+            device.apigw_jwt_key = r1.get('key')
+            device.apigw_jwt_secret = r1.get('secret')
 
 
 @receiver(pre_delete, sender=Device)
@@ -68,7 +71,7 @@ def delete_device_api_jwt(sender, instance, **kwargs):
 def delete_apigw_user_consumer(sender, instance, **kwargs):
     user = instance.user
 
-    if not user.is_superuser:
+    if not is_django_staff(user):
         profile = instance
         logger.info('Profile "{}" will be deleted, removing api gateway consumer'.format(profile))
 
@@ -91,11 +94,10 @@ def signal_handler_when_profile_is_added_to_or_removed_from_group(action, instan
     is_loaddata = getattr(instance, '__dssoa__loaddata', False)
 
     if model == Group and instance.__class__ == Profile:
-        user = instance.user
         profile = instance
+        user = profile.user
 
-        if not user.is_superuser:
-
+        if not is_django_staff(user):
             if action == 'pre_add':
                 for pk in pk_set:
                     group = Group.objects.get(id=pk)
