@@ -8,12 +8,15 @@ from allauth.account.adapter import get_adapter
 
 from ....utils import set_session_key
 from ....tokens.utils import jwt_encode
-from ..utils import get_request_device
 from ....functions import get_random_string
+from ....permissions import is_django_staff
 from ...profiles.models import Profile
-from ..models import Device
+
 from .... import app_settings
 
+from ..models import Device
+from ..utils import get_request_device
+
 logger = logging.getLogger('django_sso_app.core.apps.devices.signals')
 
 
@@ -47,7 +50,7 @@ def pre_device_save(sender, instance, **kwargs):
         user = instance.profile.user
         device = instance
 
-        if not user.is_superuser:
+        if not is_django_staff(user):
             logger.debug('Skip creating api gateway JWT for Device "{}"'.format(device))
 
             device.apigw_jwt_id = None
@@ -59,7 +62,7 @@ def pre_device_save(sender, instance, **kwargs):
 def post_user_login(**kwargs):
     user = kwargs['user']
 
-    if not user.is_superuser:
+    if not is_django_staff(user):
         request = kwargs['request']
 
         logger.debug('Devices, "{}" LOGGED IN!!!'.format(user))
