@@ -3,8 +3,7 @@
 from django.test import TestCase
 from django.contrib.auth import get_user_model
 
-from allauth.account.models import EmailAddress
-
+from ...emails.models import EmailAddress
 from ...groups.models import Group
 from ...profiles.models import Profile
 
