@@ -18,22 +18,31 @@ User = get_user_model()
 logger = logging.getLogger('django_sso_app.core.apps.profiles')
 
 
+class SsoIdPKManager(models.Manager):
+    use_in_migrations = True
+
+    def get_by_natural_key(self, sso_id):
+        return self.get(sso_id=sso_id)
+
+
 class AbstractProfileModel(CreatedAtModel, UpdatableModel, DeactivableModel, PublicableModel):
     """
     Profile abstract model
     """
+    objects = SsoIdPKManager()
 
     class Meta:
         abstract = True
 
     def natural_key(self):
-        return self.sso_id
+        return (self.sso_id,)
 
     sso_id = models.CharField(_('sso id'), max_length=36, unique=True, db_index=True, default=uuid.uuid4)  # unique on not null , editable=False
     sso_rev = models.PositiveIntegerField(_('sso revision'), default=1)
 
-    username = models.CharField(_('username'), max_length=150, null=True, blank=True)  # django
-    email = models.EmailField(_('email address'), null=True, blank=True)  # django
+    django_user_username = models.CharField(_('user username'), max_length=150, null=True, blank=True, editable=False)
+    django_user_email = models.EmailField(_('email address'), null=True, blank=True, editable=False)
+
     ssn = models.CharField(_('social security number'), max_length=255, null=True, blank=True)
     phone = models.CharField(_('phone'), max_length=255, null=True, blank=True)
 
@@ -68,20 +77,20 @@ class AbstractProfileModel(CreatedAtModel, UpdatableModel, DeactivableModel, Pub
     def is_unsubscribed(self, value):
         self.unsubscribed_at = timezone.now()
 
-    def get_absolute_url(self):
-        return reverse("django_sso_app_profile:detail", args=[self.sso_id])
+    def get_absolute_rest_url(self):
+        return reverse("django_sso_app_profile:rest-detail", args=[self.sso_id])
 
     @property
     def username(self):
         if self.user is not None:
             return self.user.username
-        return self.username
+        return self.django_user_username
 
     @property
     def email(self):
         if self.user is not None:
             return self.user.email
-        return self.email
+        return self.django_user_email
 
     def __str__(self):
         return '{}:{}:{}'.format(self.email, self.sso_id, self.username)
@@ -139,7 +148,7 @@ class Profile(AbstractProfileModel):
             logger.info('New group "{}" created'.format(g))
 
         if creating:
-            setattr(self.user, '__django_sso_app__creating', True)
+            setattr(self.user, '__dssoa__creating', True)
 
         self.groups.add(g)
 
