@@ -71,10 +71,10 @@ class ProfileSerializer(AbsoluteUrlSerializer):
                 })
         return serialized
 
-    def get_absolute_url(self, obj):
+    def get_absolute_rest_url(self, obj):
         if getattr(obj, 'id', None) is not None:
             request = self.context['request']
-            reverse_url = reverse('django_sso_app_profile:detail', args=[obj.sso_id])
+            reverse_url = reverse('django_sso_app_profile:rest-detail', args=[obj.sso_id])
 
             return request.build_absolute_uri(reverse_url)
 
@@ -82,7 +82,7 @@ class ProfileSerializer(AbsoluteUrlSerializer):
         try:
             user = instance.user
             request = self.context['request']
-            return request.build_absolute_uri(user.get_absolute_url())
+            return request.build_absolute_uri(user.get_absolute_rest_url())
         except:
             logger.warning('No profile.user url for {}.'.format(instance))
 
