@@ -20,13 +20,12 @@ def create_user_profile(sender, instance, created, **kwargs):
 
     user = instance
 
-    if not user.is_superuser:
-        if created:
-            logger.debug('user created, creating profile')
+    if created:
+        logger.debug('user created, creating profile')
 
-            profile = get_or_create_user_profile(instance, Profile, commit=True)
+        profile = get_or_create_user_profile(user, Profile, commit=True)
 
-            logger.debug('new profile created "{}"'.format(profile))
+        logger.debug('new profile created "{}"'.format(profile))
 
-            # refreshing user instance
-            instance.sso_app_profile = profile
+        # refreshing user instance
+        user.sso_app_profile = profile
