@@ -6,6 +6,7 @@ import logging
 from django.contrib.auth import get_user_model
 
 from ...utils import is_test_user
+from ...permissions import is_django_staff
 from ... import app_settings
 
 User = get_user_model()
@@ -45,6 +46,15 @@ def get_or_create_user_profile(user, ProfileModel, initials=None, commit=True):
             sso_rev = getattr(user, '__dssoa__profile__sso_rev', 0)
             profile.sso_id = sso_id
             profile.sso_rev = sso_rev
+        else:
+            # django staff users sso_id equals username
+            if is_django_staff(user):
+                profile.sso_id = user.username
+                profile.sso_rev = 0
+
+                setattr(user, '__dssoa__creating', True)
+                
+                profile.save()
 
         # test user
         if is_test_user(user):
