@@ -55,11 +55,9 @@ class ProfileView(LoginRequiredMixin, WebpackBuiltTemplateViewMixin):
     def get(self, request, *args, **kwargs):
         logger.info('Getting profile')
 
-        if request.user.is_superuser:
-            return(redirect(reverse('admin:index')))
-
         try:
             return super(ProfileView, self).get(request, *args, **kwargs)
+
         except:
             logger.exception('Error getting profile')
             raise
@@ -87,9 +85,6 @@ class ProfileUpdateView(LoginRequiredMixin, UpdateView, WebpackBuiltTemplateView
     def get(self, request, *args, **kwargs):
         logger.info('Getting profile update')
 
-        if request.user.is_superuser:
-            return (redirect(reverse('admin:index')))
-
         try:
             profile = self.get_object()
             return super(ProfileUpdateView, self).get(request, profile.pk, *args, **kwargs)
@@ -101,9 +96,6 @@ class ProfileUpdateView(LoginRequiredMixin, UpdateView, WebpackBuiltTemplateView
     def post(self, request, *args, **kwargs):
         logger.info('Posting profile update')
 
-        if request.user.is_superuser:
-            return (redirect(reverse('admin:index')))
-
         try:
             profile = self.get_object()
             response = super(ProfileUpdateView, self).post(request, profile.pk, *args, **kwargs)
