@@ -36,8 +36,8 @@ class Service(CreatedAtModel, UpdatableModel, PublicableModel, DeactivableModel)
     def __str__(self):
         return '{}:{}'.format(self.name, self.service_url)
 
-    def get_absolute_url(self):
-        return reverse("django_sso_app_service:detail", args=[self.pk])
+    def get_absolute_rest_url(self):
+        return reverse("django_sso_app_service:rest-detail", args=[self.pk])
 
 
 class TOS(CreatedAtModel, UpdatableModel, DeactivableModel):
@@ -90,5 +90,5 @@ class Subscription(CreatedAtModel, UpdatableModel, DeactivableModel, PublicableM
     def __str__(self):
         return '{}@{}'.format(self.profile, self.service.service_url)
 
-    def get_absolute_url(self):
-        return reverse("django_sso_app_service:subscription-detail", args=[self.pk])
+    def get_absolute_rest_url(self):
+        return reverse("django_sso_app_service:rest-subscription-detail", args=[self.pk])
