@@ -197,24 +197,17 @@ class TestServices(UserTestCase):
         first_rev = self.profile.sso_rev
 
         response = self.client.post(
-            reverse('rest_login'),
-            data=json.dumps(self.valid_staff_login),
-            content_type='application/json'
-        )
-        cookies = response.cookies
-
-        response2 = self.client.post(
             reverse('django_sso_app_service:rest-subscription', args=(self.service2.id, )),
             data=json.dumps({'sso_id': str(self.profile.sso_id)}),
-            content_type='application/json'
+            **self.staff_user_valid_token_headers
         )
-        cookies2 = response2.cookies
+        cookies2 = response.cookies
 
-        print('\n\nRISPOSTA', response2.json())
+        print('\n\nRISPOSTA', response.json())
 
-        self.assertEqual(response2.status_code, status.HTTP_201_CREATED)
+        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
-        self.assertEqual(response2.data, 'Successfully subscribed.')
+        self.assertEqual(response.data, 'Successfully subscribed.')
 
         self.profile.refresh_from_db()
         second_rev = self.profile.sso_rev
