@@ -7,28 +7,28 @@ from .views import ServiceApiViewSet, SubscriptionApiViewSet, ServiceSubscriptio
 _service__urlpatterns = [
     url(r'^$',
         ServiceApiViewSet.as_view({'get': 'list'}),
-        name='list'),
+        name='rest-list'),
     url(r'^(?P<pk>\d+)/$',
         ServiceApiViewSet.as_view({'get': 'retrieve'}),
-        name='detail'),
+        name='rest-detail'),
 
     url(r'^(?P<pk>\d+)/subscribe/$',
         ServiceSubscriptionApiViewSet.as_view({'post': 'subscribe'}),
-        name='subscription'),
+        name='rest-subscription'),
 
     url(r'^(?P<pk>\d+)/unsubscribe/$',
         ServiceSubscriptionApiViewSet.as_view({'post': 'unsubscribe'}),
-        name='unsubscription'),
+        name='rest-unsubscription'),
 ]
 
 _subscription_urlpatterns = [
     url(r'^subscriptions/$',
         SubscriptionApiViewSet.as_view({'get': 'list'}),
-        name='subscription-list'),
+        name='rest-subscription-list'),
 
     url(r'^subscriptions/(?P<pk>\d+)/$',
         SubscriptionApiViewSet.as_view({'get': 'retrieve'}),
-        name='subscription-detail'),
+        name='rest-subscription-detail'),
 ]
 
 service_urlpatterns = format_suffix_patterns(_service__urlpatterns)
