@@ -5,7 +5,7 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.auth.hashers import get_hasher, identify_hasher
 
-from ... import app_settings
+# from ... import app_settings
 
 logger = logging.getLogger('django_sso_app.core.apps.users')
 
