@@ -22,7 +22,7 @@ class TestUserCreate(UserTestCase):
     def test_staff_user_can_create_user_with_profile_with_unverified_email(self):
         print('HEADERS', self.staff_user_valid_token_headers, type(self.staff_user_valid_token_headers))
         response = self.client.post(
-            reverse('django_sso_app_user:list'),
+            reverse('django_sso_app_user:rest-list'),
             data=json.dumps(self.valid_new_external_user),
             **self.staff_user_valid_token_headers
         )
@@ -32,7 +32,7 @@ class TestUserCreate(UserTestCase):
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         response2 = self.client.get(
-            reverse('django_sso_app_user:detail', args=(new_user_sso_id,)),
+            reverse('django_sso_app_user:rest-detail', args=(new_user_sso_id,)),
             **self.staff_user_valid_token_headers
         )
 
@@ -46,7 +46,7 @@ class TestUserCreate(UserTestCase):
         print('HEADERS', self.staff_user_valid_token_headers, type(self.staff_user_valid_token_headers))
 
         response = self.client.post(
-            reverse('django_sso_app_user:list') + '?skip_confirmation=true',
+            reverse('django_sso_app_user:rest-list') + '?skip_confirmation=true',
             data=json.dumps(self.valid_new_external_user),
             **self.staff_user_valid_token_headers
         )
@@ -56,7 +56,7 @@ class TestUserCreate(UserTestCase):
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         response2 = self.client.get(
-            reverse('django_sso_app_user:detail', args=(new_user_sso_id,)),
+            reverse('django_sso_app_user:rest-detail', args=(new_user_sso_id,)),
             **self.staff_user_valid_token_headers
         )
 
@@ -75,7 +75,7 @@ class TestUserCreate(UserTestCase):
         )
 
         response = self.client.post(
-            reverse('django_sso_app_user:list') + '?skip_confirmation=true',
+            reverse('django_sso_app_user:rest-list') + '?skip_confirmation=true',
             data=json.dumps(self.valid_new_external_user),
             content_type='application/json'
         )
@@ -87,7 +87,7 @@ class TestUserCreate(UserTestCase):
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         response2 = self.client.get(
-            reverse('django_sso_app_user:detail', args=(new_user_sso_id,)),
+            reverse('django_sso_app_user:rest-detail', args=(new_user_sso_id,)),
             **self.staff_user_valid_token_headers
         )
 
@@ -129,7 +129,7 @@ class TestUserRetrieve(UserTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
         response2 = self.client.get(
-            reverse('django_sso_app_user:detail', args=(self.profile.sso_id,)),
+            reverse('django_sso_app_user:rest-detail', args=(self.profile.sso_id,)),
             content_type='application/json'
         )
         print('RESP', response2.data)
@@ -138,7 +138,7 @@ class TestUserRetrieve(UserTestCase):
     def test_staff_user_can_retrieve_user_with_token(self):
 
         response2 = self.client.get(
-            reverse('django_sso_app_user:detail', args=(self.profile.sso_id,)),
+            reverse('django_sso_app_user:rest-detail', args=(self.profile.sso_id,)),
             **self.staff_user_valid_token_headers
         )
         print('RESP', response2.data)
@@ -160,7 +160,7 @@ class TestUserUpdate(UserTestCase):
 
         print('\n sending patch from user', self.user, 'with new email', self.valid_email_update)
         response2 = self.client.patch(
-            reverse('django_sso_app_user:detail', args=[self.profile.sso_id]),
+            reverse('django_sso_app_user:rest-detail', args=[self.profile.sso_id]),
             data=json.dumps(self.valid_email_update),
             content_type='application/json'
         )
@@ -235,7 +235,7 @@ class TestUserUpdate(UserTestCase):
         self.assertEqual(response.status_code, 200, 'unable to login with valid credentials')
 
         response2 = self.client.patch(
-            reverse('django_sso_app_user:detail', args=[self.profile.sso_id]),
+            reverse('django_sso_app_user:rest-detail', args=[self.profile.sso_id]),
             data=json.dumps(self.valid_password_update),
             content_type='application/json'
         )
