@@ -12,6 +12,7 @@ from django.db.models import Q
 from django.core.exceptions import SuspiciousOperation
 
 from allauth.account.adapter import get_adapter
+from allauth.account.utils import filter_users_by_username, filter_users_by_email
 
 from rest_framework import generics
 from rest_framework import mixins
@@ -54,12 +55,14 @@ class CheckUserExistenceApiView(APIView):
                     return email_address.user
 
             elif username is None and email is not None:
-                email_address = EmailAddress.objects.filter(email=email, verified=True).first()
-                if email_address is not None:
-                    return email_address.user
+                users = filter_users_by_email(email)
+                if len(users):
+                    return users[0]
 
             elif username is not None and email is None:
-                return User.objects.get(username=username)
+                users = filter_users_by_username(username)
+                if len(users):
+                    return users[0]
 
             raise User.DoesNotExist('Either login username or email must be set.')
 
