@@ -6,7 +6,7 @@ class BaseException(Exception):
         self.msg = str(msg)
 
 
-class AdminUserCanNotLoginException(BaseException):
+class DjangoStaffUsersCanNotLoginException(BaseException):
     pass
 
 
