@@ -12,7 +12,7 @@ from django.utils.encoding import smart_str
 from django.conf import settings
 
 from ..tokens.utils import get_request_jwt, jwt_decode
-from ..permissions import is_authenticated, is_staff
+from ..permissions import is_authenticated, is_django_staff
 from ..exceptions import ServiceSubscriptionRequiredException, RequestHasValidJwtWithNoDeviceAssociated
 from ..utils import check_user_can_login  # , set_session_key
 from ..apps.api_gateway.functions import get_apigateway_sso_id
@@ -21,6 +21,7 @@ from ... import app_settings
 logger = logging.getLogger('django_sso_app.core.middleware')
 
 ADMIN_URL = '/{}'.format(settings.ADMIN_URL)
+SSO_ID_JWT_KEY = 'sso_id'
 
 
 class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
@@ -50,6 +51,16 @@ class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
         auth.logout(request)
 
     def process_request(self, request):
+
+        # AuthenticationMiddleware is required so that request.user exists.
+        if not hasattr(request, 'user'):
+            raise ImproperlyConfigured(
+                "SSO middleware requires the authentication middleware to be"
+                " installed.  Edit your MIDDLEWARE setting to insert"
+                " 'django.contrib.auth.middleware.AuthenticationMiddleware'"
+                " before the SsoMiddleware class.")
+
+
         # saving request info
         self.request_method = request.method
         self.request_path = request.path
@@ -61,33 +72,32 @@ class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
                                                                          self.request_path,
                                                                          self.request_method))
 
-        # AuthenticationMiddleware is required so that request.user exists.
-        if not hasattr(request, 'user'):
-            raise ImproperlyConfigured(
-                "SSO middleware requires the authentication middleware to be"
-                " installed.  Edit your MIDDLEWARE setting to insert"
-                " 'django.contrib.auth.middleware.AuthenticationMiddleware'"
-                " before the SsoMiddleware class.")
+        # requesting user
+        request_user = request.user
 
-        if request.user.is_superuser:
-            logger.info('skipping admin user')
+
+        # skipping django staff users
+        if is_django_staff(request_user):
+            logger.info('Skipping django staff user "{}"'.format(request_user))
             #  >= 1.10 has is_authenticated as parameter
             # If a staff user is already authenticated, we don't need to
             # continue
-            # set_session_key(request, '__dssoa__user', request.user)
+            # set_session_key(request, '__dssoa__user', request_user)
             return
 
+
         if self.request_path.startswith(ADMIN_URL):
-            logger.info('skipping admin path')
             #  >= 1.10 has is_authenticated as parameter
             # If a staff user is already authenticated, we don't need to
             # continue
-            if is_authenticated(request.user):
-                if not request.user.is_superuser and not is_staff(request.user):
-                    _msg = 'User "{}" tried to enter admin path'.format(request.user)
-                    logger.warning(_msg)
+            if is_authenticated(request_user):
+                _msg = 'Non staff user "{}" tried to enter admin path'.format(request_user)
+                logger.warning(_msg)
+
+                self._remove_invalid_user(request)
+            else:
+                logger.info('Skipping admin path')
 
-                    self._remove_invalid_user(request)
             return
 
         """
@@ -98,7 +108,6 @@ class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
 
         consumer_username = None
         request_jwt = None
-        decoded_jwt = None
         verify_jwt = True
 
         if app_settings.APIGATEWAY_ENABLED:
@@ -107,7 +116,7 @@ class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
                 consumer_username = request.META[self.header]
 
                 if consumer_username == self.anonymous_username:
-                    if is_authenticated(request.user):
+                    if is_authenticated(request_user):
                         logger.info('consumer is anonymous, returning')
                         self._remove_invalid_user(request)
                     return
@@ -116,7 +125,7 @@ class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
                 # If specified header or jwt doesn't exist then remove any existing
                 # authenticated user, or return (leaving request.user set to
                 # AnonymousUser by the AuthenticationMiddleware).
-                if is_authenticated(request.user):
+                if is_authenticated(request_user):
                     logger.info('authentication middleware KeyError "{}"'.format(e))
                     self._remove_invalid_user(request)
                 return
@@ -124,55 +133,60 @@ class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
             else:
                 sso_id = get_apigateway_sso_id(consumer_username)
 
+
         # validating request jwt
 
         try:
             request_jwt = get_request_jwt(request, encoded=False)
 
-            if request_jwt is not None:
-                request_device, decoded_jwt = jwt_decode(request_jwt, verify=verify_jwt)
-            else:
-                logger.debug('no JWT in request')
+            if request_jwt is None:
+                # If request has no JWT authentication skips
+                logger.info('No JWT in request, skipping')
                 return
+            else:
+                # decoding request JWT
+                request_device, decoded_jwt = jwt_decode(request_jwt, verify=verify_jwt)
 
         except KeyError:
-            logger.debug('Error decoding JWT "{}"'.format(request_jwt))
+            logger.warning('Error decoding JWT "{}"'.format(request_jwt))
 
-            if is_authenticated(request.user):
+            if is_authenticated(request_user):
                 self._remove_invalid_user(request)
             return
 
         except InvalidSignatureError:
             logger.warning('Invalid JWT signature "{}"'.format(request_jwt))
 
-            if is_authenticated(request.user):
+            if is_authenticated(request_user):
                 self._remove_invalid_user(request)
             return
 
         else:
-            if decoded_jwt is not None:
-                sso_id = decoded_jwt['sso_id']
+            if decoded_jwt is None:
+                logger.warning('No decoded JWT for "{}"'.format(request_jwt))
+            else:
+                sso_id = decoded_jwt[SSO_ID_JWT_KEY]
 
 
         # If the user is already authenticated and that user is active and the
         # one we are getting passed in the headers, then the correct user is
         # already persisted in the session and we don't need to continue.
 
-        if is_authenticated(request.user):
-            user_profile = request.user
-
+        # double check sso_id equality between received jwt and sso_app_profile
+        if is_authenticated(request_user):
             # check declared sso_id
-            if smart_str(user_profile.sso_id) == sso_id:
+            if smart_str(request_user.sso_id) == sso_id:
                 logger.debug('user is ok')
-                #set_session_key(request, '__dssoa__user', request.user)
+                #set_session_key(request, '__dssoa__user', request_user)
                 return
             else:
                 # An authenticated user is associated with the request, but
                 # it does not match the authorized user in the header.
-                logger.warning('sso_id differs! "{}" "{}"'.format(sso_id, user_profile.sso_id))
+                logger.warning('sso_id differs! "{}" "{}"'.format(sso_id, request_user.sso_id))
                 self._remove_invalid_user(request)
                 return
 
+
         # We are seeing this user for the first time in this session, attempt
         # to authenticate the user.
         try:
@@ -188,7 +202,7 @@ class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
 
         except ServiceSubscriptionRequiredException as e:
             logger.info('ServiceSubscriptionRequiredException')
-            if is_authenticated(request.user) and app_settings.APP_ENABLED:
+            if is_authenticated(request_user) and app_settings.APP_ENABLED:
                 self._remove_invalid_user(request)
 
             return e.response
@@ -196,14 +210,14 @@ class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
         except RequestHasValidJwtWithNoDeviceAssociated:
             logger.exception('RequestHasValidJwtWithNoDeviceAssociated')
 
-            if is_authenticated(request.user):
+            if is_authenticated(request_user):
                 self._remove_invalid_user(request)
 
             return
 
         except Exception as e:
             logger.exception('generic middleware exception "{}"'.format(e))
-            if is_authenticated(request.user):
+            if is_authenticated(request_user):
                 self._remove_invalid_user(request)
             return
 
@@ -217,9 +231,9 @@ class DjangoSsoAppAuthenticationMiddleware(MiddlewareMixin):
                 check_user_can_login(user)
 
             except Exception as e:
-                logger.exception('middleware error authenticating "{}"'.format(e))
+                logger.exception('Authentication middleware check_user_can_login exception "{}"'.format(e))
 
-                if is_authenticated(request.user):
+                if is_authenticated(request_user):
                     self._remove_invalid_user(request)
 
                 return
