@@ -12,7 +12,7 @@ from rest_framework import status
 from allauth.account import views as allauth_account_views
 from allauth.socialaccount import views as allauth_socialaccount_views
 
-from .permissions import is_staff, is_authenticated
+from .permissions import is_django_staff, is_authenticated
 from .utils import set_cookie, invalidate_cookie, set_session_key, get_session_key, get_random_fingerprint
 from .mixins import WebpackBuiltTemplateViewMixin
 from . import app_settings
@@ -35,7 +35,7 @@ class DjangoSsoAppBaseViewMixin():
     @staticmethod
     def get_response_with_cookie(request, response):
         if is_authenticated(request.user):
-            if not request.user.is_superuser:
+            if not is_django_staff(request.user):
                 token = get_session_key(request, '__dssoa__jwt_token')
                 set_cookie(response, app_settings.JWT_COOKIE_NAME, token)
 
@@ -147,6 +147,12 @@ class SignupView(allauth_account_views.SignupView, DjangoSsoAppBaseViewMixin, We
             raise
 
         else:
+            # log signup failed
+            if response.status_code != '302':
+                if hasattr(response, 'render'):
+                    response.render()
+                logger.warning('User failed to register: "{}"'.format(response.content))
+
             if is_authenticated(request.user):
                 logger.debug('signup login disabled')
                 django_logout(request)
